@@ -40,7 +40,6 @@ options:
 examples:
     ia reviews nasa
 """
-from __future__ import absolute_import, print_function
 import sys
 
 from docopt import docopt
@@ -67,13 +66,13 @@ def main(argv, session):
         r = item.review(args['--title'], args['--body'], args['--stars'])
     j = r.json()
     if j.get('success') or 'no change detected' in j.get('error', '').lower():
-        task_id = j.get('value', dict()).get('task_id')
+        task_id = j.get('value', {}).get('task_id')
         if task_id:
-            print('{} - success: https://catalogd.archive.org/log/{}'.format(
-                item.identifier, task_id))
+            print(f'{item.identifier} - success: https://catalogd.archive.org/log/{task_id}',
+                  file=sys.stderr)
         else:
-            print('{} - warning: no changes detected!'.format(item.identifier))
+            print(f'{item.identifier} - warning: no changes detected!', file=sys.stderr)
         sys.exit(0)
     else:
-        print('{} - error: {}'.format(item.identifier, j.get('error')))
+        print(f'{item.identifier} - error: {j.get("error")}', file=sys.stderr)
         sys.exit(1)
