@@ -59,40 +59,32 @@ options:
     --no-backup                          Turn off archive.org backups. Clobbered files
                                          will not be saved to history/files/$key.~N~
                                          [default: True].
+    --keep-directories                   Keep directories in the supplied file paths for
+                                         the remote filename. [default: False]
 """
-from __future__ import absolute_import, unicode_literals, print_function
-
-import io
 import os
 import sys
 from tempfile import TemporaryFile
 from copy import deepcopy
 import webbrowser
-import json
+import csv
+from locale import getpreferredencoding
 
-import six
 from docopt import docopt, printable_usage
 from requests.exceptions import HTTPError
 from schema import Schema, Use, Or, And, SchemaError
 
 from internetarchive.cli.argparser import get_args_dict, convert_str_list_to_unicode
 from internetarchive.session import ArchiveSession
-from internetarchive.utils import (InvalidIdentifierException, get_s3_xml_text,
-                                   is_valid_metadata_key, validate_s3_identifier)
-
-# Only import backports.csv for Python2 (in support of FreeBSD port).
-PY2 = sys.version_info[0] == 2
-if PY2:
-    from backports import csv
-else:
-    import csv
+from internetarchive.utils import (InvalidIdentifierException, JSONDecodeError, get_s3_xml_text,
+                                   is_valid_metadata_key, json, validate_s3_identifier)
 
 
 def _upload_files(item, files, upload_kwargs, prev_identifier=None, archive_session=None):
     """Helper function for calling :meth:`Item.upload`"""
     responses = []
     if (upload_kwargs['verbose']) and (prev_identifier != item.identifier):
-        print('{0}:'.format(item.identifier))
+        print(f'{item.identifier}:', file=sys.stderr)
 
     try:
         response = item.upload(files, **upload_kwargs)
@@ -100,40 +92,25 @@ def _upload_files(item, files, upload_kwargs, prev_identifier=None, archive_sess
     except HTTPError as exc:
         responses += [exc.response]
     except InvalidIdentifierException as exc:
-        print(str(exc))
+        print(str(exc), file=sys.stderr)
         sys.exit(1)
     finally:
         # Debug mode.
         if upload_kwargs['debug']:
             for i, r in enumerate(responses):
                 if i != 0:
-                    print('---')
+                    print('---', file=sys.stderr)
                 headers = '\n'.join(
-                    [' {0}:{1}'.format(k, v) for (k, v) in r.headers.items()]
+                    [f' {k}:{v}' for (k, v) in r.headers.items()]
                 )
-                print('Endpoint:\n {0}\n'.format(r.url))
-                print('HTTP Headers:\n{0}'.format(headers))
-                return responses
-
-        # Format error message for any non 200 responses that
-        # we haven't caught yet,and write to stderr.
-        if responses and responses[-1].status_code and responses[-1].status_code != 200:
-            if not responses[-1].status_code:
-                return responses
-            filename = responses[-1].request.url.split('/')[-1]
-            try:
-                msg = get_s3_xml_text(responses[-1].content)
-            except:
-                msg = responses[-1].content
+                print(f'Endpoint:\n {r.url}\n', file=sys.stderr)
+                print(f'HTTP Headers:\n{headers}', file=sys.stderr)
 
     return responses
 
 
 def main(argv, session):
-    if six.PY2:
-        args = docopt(__doc__.encode('utf-8'), argv=argv)
-    else:
-        args = docopt(__doc__, argv=argv)
+    args = docopt(__doc__, argv=argv)
     ERRORS = False
 
     # Validate args.
@@ -145,13 +122,11 @@ def main(argv, session):
                    'underscores "_", or dashes "-". However, <identifier> cannot begin '
                    'with periods, underscores, or dashes.'))),
         '<file>': And(
-            Use(lambda l: l if not six.PY2 else convert_str_list_to_unicode(l)),
             And(lambda f: all(os.path.exists(x) for x in f if x != '-'),
                 error='<file> should be a readable file or directory.'),
             And(lambda f: False if f == ['-'] and not args['--remote-name'] else True,
                 error='--remote-name must be provided when uploading from stdin.')),
-        '--remote-name': Or(None,
-            Use(lambda x: x.decode(sys.getfilesystemencoding()) if six.PY2 else x)),
+        '--remote-name': Or(None, str),
         '--spreadsheet': Or(None, os.path.isfile,
                             error='--spreadsheet should be a readable file.'),
         '--file-metadata': Or(None, os.path.isfile,
@@ -169,7 +144,7 @@ def main(argv, session):
     try:
         args = s.validate(args)
     except SchemaError as exc:
-        print('{0}\n{1}'.format(str(exc), printable_usage(__doc__)), file=sys.stderr)
+        print(f'{exc}\n{printable_usage(__doc__)}', file=sys.stderr)
         sys.exit(1)
 
     # Make sure the collection being uploaded to exists.
@@ -180,20 +155,19 @@ def main(argv, session):
         collection = session.get_item(collection_id)
         if not collection.exists:
             print('You must upload to a collection that exists. '
-                  '"{0}" does not exist.\n{1}'.format(collection_id,
-                                                      printable_usage(__doc__)),
+                  f'"{collection_id}" does not exist.\n{printable_usage(__doc__)}',
                   file=sys.stderr)
             sys.exit(1)
 
     # Status check.
     if args['--status-check']:
         if session.s3_is_overloaded():
-            print('warning: {0} is over limit, and not accepting requests. '
-                  'Expect 503 SlowDown errors.'.format(args['<identifier>']),
+            print(f'warning: {args["<identifier>"]} is over limit, and not accepting requests. '
+                  'Expect 503 SlowDown errors.',
                   file=sys.stderr)
             sys.exit(1)
         else:
-            print('success: {0} is accepting requests.'.format(args['<identifier>']))
+            print(f'success: {args["<identifier>"]} is accepting requests.', file=sys.stderr)
             sys.exit()
 
     elif args['<identifier>']:
@@ -211,31 +185,50 @@ def main(argv, session):
 
     if args['--file-metadata']:
         try:
-            args['<file>'] = json.load(open(args['--file-metadata']))
-        except json.decoder.JSONDecodeError:
-            args['<file>'] = list()
-            for line in open(args['--file-metadata']):
-                j = json.loads(line.strip())
-                args['<file>'].append(j)
-    upload_kwargs = dict(
-        metadata=args['--metadata'],
-        headers=args['--header'],
-        debug=args['--debug'],
-        queue_derive=queue_derive,
-        verbose=verbose,
-        verify=args['--verify'],
-        checksum=args['--checksum'],
-        retries=args['--retries'],
-        retries_sleep=args['--sleep'],
-        delete=args['--delete'],
-        validate_identifier=True
-    )
+            with open(args['--file-metadata']) as fh:
+                args['<file>'] = json.load(fh)
+        except JSONDecodeError:
+            args['<file>'] = []
+            with open(args['--file-metadata']) as fh:
+                for line in fh:
+                    j = json.loads(line.strip())
+                    args['<file>'].append(j)
+    upload_kwargs = {
+        'metadata': args['--metadata'],
+        'headers': args['--header'],
+        'debug': args['--debug'],
+        'queue_derive': queue_derive,
+        'verbose': verbose,
+        'verify': args['--verify'],
+        'checksum': args['--checksum'],
+        'retries': args['--retries'],
+        'retries_sleep': args['--sleep'],
+        'delete': args['--delete'],
+        'validate_identifier': True,
+    }
 
     # Upload files.
     if not args['--spreadsheet']:
         if args['-']:
             local_file = TemporaryFile()
-            local_file.write(sys.stdin.read())
+            # sys.stdin normally has the buffer attribute which returns bytes.
+            # However, this might not always be the case, e.g. on mocking for test purposes.
+            # Fall back to reading as str and encoding back to bytes.
+            # Note that the encoding attribute might also be None. In that case, fall back to
+            # locale.getpreferredencoding, the default of io.TextIOWrapper and open().
+            if hasattr(sys.stdin, 'buffer'):
+                def read():
+                    return sys.stdin.buffer.read(1048576)
+            else:
+                encoding = sys.stdin.encoding or getpreferredencoding(False)
+
+                def read():
+                    return sys.stdin.read(1048576).encode(encoding)
+            while True:
+                data = read()
+                if not data:
+                    break
+                local_file.write(data)
             local_file.seek(0)
         else:
             local_file = args['<file>']
@@ -244,6 +237,8 @@ def main(argv, session):
             local_file = local_file[0]
         if args['--remote-name']:
             files = {args['--remote-name']: local_file}
+        elif args['--keep-directories']:
+            files = {f: f for f in local_file}
         else:
             files = local_file
 
@@ -254,43 +249,45 @@ def main(argv, session):
                 ERRORS = True
             else:
                 if args['--open-after-upload']:
-                    webbrowser.open_new_tab('{}//{}/details/{}'.format(
-                        session.protocol, session.host, item.identifier))
+                    url = f'{session.protocol}//{session.host}/details/{item.identifier}'
+                    webbrowser.open_new_tab(url)
 
     # Bulk upload using spreadsheet.
     else:
         # Use the same session for each upload request.
-        with io.open(args['--spreadsheet'], 'rU', newline='', encoding='utf-8') as csvfp:
+        with open(args['--spreadsheet'], 'r', newline='', encoding='utf-8-sig') as csvfp:
             spreadsheet = csv.DictReader(csvfp)
             prev_identifier = None
             for row in spreadsheet:
                 for metadata_key in row:
                     if not is_valid_metadata_key(metadata_key):
-                        print('error: "%s" is not a valid metadata key.' % metadata_key,
+                        print(f'error: "{metadata_key}" is not a valid metadata key.',
                               file=sys.stderr)
                         sys.exit(1)
                 upload_kwargs_copy = deepcopy(upload_kwargs)
                 if row.get('REMOTE_NAME'):
                     local_file = {row['REMOTE_NAME']: row['file']}
                     del row['REMOTE_NAME']
+                elif args['--keep-directories']:
+                    local_file = {row['file']: row['file']}
                 else:
                     local_file = row['file']
                 identifier = row.get('item', row.get('identifier'))
                 if not identifier:
-                    print('error: no identifier column on spreadsheet.',
-                          file=sys.stderr)
-                    sys.exit(1)
+                    if not prev_identifier:
+                        print('error: no identifier column on spreadsheet.',
+                              file=sys.stderr)
+                        sys.exit(1)
+                    identifier = prev_identifier
                 del row['file']
                 if 'identifier' in row:
                     del row['identifier']
-                elif 'item' in row:
+                if 'item' in row:
                     del row['item']
-                if (not identifier) and (prev_identifier):
-                    identifier = prev_identifier
                 item = session.get_item(identifier)
                 # TODO: Clean up how indexed metadata items are coerced
                 # into metadata.
-                md_args = ['{0}:{1}'.format(k.lower(), v) for (k, v) in row.items() if v]
+                md_args = [f'{k.lower()}:{v}' for (k, v) in row.items() if v]
                 metadata = get_args_dict(md_args)
                 upload_kwargs_copy['metadata'].update(metadata)
                 r = _upload_files(item, local_file, upload_kwargs_copy, prev_identifier,
@@ -298,12 +295,12 @@ def main(argv, session):
                 for _r in r:
                     if args['--debug']:
                         break
-                    if (not _r) or (not _r.ok):
+                    if (not _r.status_code) or (not _r.ok):
                         ERRORS = True
                     else:
                         if args['--open-after-upload']:
-                            webbrowser.open_new_tab('{}//{}/details/{}'.format(
-                                session.protocol, session.host, identifier))
+                            url = f'{session.protocol}//{session.host}/details/{identifier}'
+                            webbrowser.open_new_tab(url)
                 prev_identifier = identifier
 
     if ERRORS:
