@@ -24,17 +24,15 @@ internetarchive.files
 :copyright: (C) 2012-2019 by Internet Archive.
 :license: AGPL 3, see LICENSE for more details.
 """
-from __future__ import absolute_import, unicode_literals, print_function
-
 import os
 import sys
 import logging
 import socket
-
-import six.moves.urllib as urllib
-import six
+from urllib.parse import quote
 from requests.exceptions import HTTPError, RetryError, ConnectTimeout, \
     ConnectionError, ReadTimeout
+from tqdm import tqdm
+from contextlib import nullcontext
 
 from internetarchive import iarequest, utils, auth
 
@@ -42,11 +40,11 @@ from internetarchive import iarequest, utils, auth
 log = logging.getLogger(__name__)
 
 
-class BaseFile(object):
+class BaseFile:
 
     def __init__(self, item_metadata, name, file_metadata=None):
         if file_metadata is None:
-            file_metadata = dict()
+            file_metadata = {}
         name = name.strip('/')
         if not file_metadata:
             for f in item_metadata.get('files', []):
@@ -113,19 +111,14 @@ class File(BaseFile):
         :param file_metadata: (optional) a dict of metadata for the
                               given file.
         """
-        if six.PY2:
-            try:
-                name = name.decode('utf-8')
-            except UnicodeEncodeError:
-                pass
-        super(File, self).__init__(item.item_metadata, name, file_metadata)
+        super().__init__(item.item_metadata, name, file_metadata)
         self.item = item
-        url_parts = dict(
-            protocol=item.session.protocol,
-            id=self.identifier,
-            name=urllib.parse.quote(name.encode('utf-8')),
-            host=item.session.host,
-        )
+        url_parts = {
+            'protocol': item.session.protocol,
+            'id': self.identifier,
+            'name': quote(name.encode('utf-8')),
+            'host': item.session.host,
+        }
         self.url = '{protocol}//{host}/download/{id}/{name}'.format(**url_parts)
         if self.item.session.access_key and self.item.session.secret_key:
             self.auth = auth.S3Auth(self.item.session.access_key,
@@ -134,12 +127,12 @@ class File(BaseFile):
             self.auth = None
 
     def __repr__(self):
-        return ('File(identifier={identifier!r}, '
-                'filename={name!r}, '
-                'size={size!r}, '
-                'format={format!r})'.format(**self.__dict__))
+        return (f'File(identifier={self.identifier!r}, '
+                f'filename={self.name!r}, '
+                f'size={self.size!r}, '
+                f'format={self.format!r})')
 
-    def download(self, file_path=None, verbose=None, silent=None, ignore_existing=None,
+    def download(self, file_path=None, verbose=None, ignore_existing=None,
                  checksum=None, destdir=None, retries=None, ignore_errors=None,
                  fileobj=None, return_responses=None, no_change_timestamp=None,
                  params=None, chunk_size=None):
@@ -151,9 +144,6 @@ class File(BaseFile):
         :type verbose: bool
         :param verbose: (optional) Turn on verbose output.
 
-        :type silent: bool
-        :param silent: (optional) Suppress all output.
-
         :type ignore_existing: bool
         :param ignore_existing: Overwrite local files if they already
                                 exist.
@@ -201,11 +191,6 @@ class File(BaseFile):
         no_change_timestamp = False if not no_change_timestamp else no_change_timestamp
         params = None if not params else params
 
-        if (fileobj and silent is None) or silent is not False:
-            silent = True
-        else:
-            silent = False
-
         self.item.session.mount_http_adapter(max_retries=retries)
         file_path = self.name if not file_path else file_path
 
@@ -213,45 +198,34 @@ class File(BaseFile):
             if not os.path.exists(destdir) and return_responses is not True:
                 os.mkdir(destdir)
             if os.path.isfile(destdir):
-                raise IOError('{} is not a directory!'.format(destdir))
+                raise IOError(f'{destdir} is not a directory!')
             file_path = os.path.join(destdir, file_path)
 
         if not return_responses and os.path.exists(file_path.encode('utf-8')):
             if ignore_existing:
-                msg = 'skipping {0}, file already exists.'.format(file_path)
+                msg = f'skipping {file_path}, file already exists.'
                 log.info(msg)
                 if verbose:
-                    print(' ' + msg)
-                elif silent is False:
-                    print('.', end='')
-                    sys.stdout.flush()
+                    print(f' {msg}', file=sys.stderr)
                 return
             elif checksum:
                 with open(file_path, 'rb') as fp:
                     md5_sum = utils.get_md5(fp)
 
                 if md5_sum == self.md5:
-                    msg = ('skipping {0}, '
-                           'file already exists based on checksum.'.format(file_path))
+                    msg = f'skipping {file_path}, file already exists based on checksum.'
                     log.info(msg)
                     if verbose:
-                        print(' ' + msg)
-                    elif silent is False:
-                        print('.', end='')
-                        sys.stdout.flush()
+                        print(f' {msg}', file=sys.stderr)
                     return
             else:
                 st = os.stat(file_path.encode('utf-8'))
                 if (st.st_mtime == self.mtime) and (st.st_size == self.size) \
                         or self.name.endswith('_files.xml') and st.st_size != 0:
-                    msg = ('skipping {0}, file already exists '
-                           'based on length and date.'.format(file_path))
+                    msg = f'skipping {file_path}, file already exists based on length and date.'
                     log.info(msg)
                     if verbose:
-                        print(' ' + msg)
-                    elif silent is False:
-                        print('.', end='')
-                        sys.stdout.flush()
+                        print(f' {msg}', file=sys.stderr)
                     return
 
         parent_dir = os.path.dirname(file_path)
@@ -270,28 +244,36 @@ class File(BaseFile):
             if return_responses:
                 return response
 
+            if verbose:
+                total = int(response.headers.get('content-length', 0)) or None
+                progress_bar = tqdm(desc=f' downloading {self.name}',
+                                    total=total,
+                                    unit='iB',
+                                    unit_scale=True,
+                                    unit_divisor=1024)
+            else:
+                progress_bar = nullcontext()
+
             if not chunk_size:
-                chunk_size = 1000000
+                chunk_size = 1048576
             if not fileobj:
                 fileobj = open(file_path.encode('utf-8'), 'wb')
 
-            with fileobj:
+            with fileobj, progress_bar as bar:
                 for chunk in response.iter_content(chunk_size=chunk_size):
                     if chunk:
-                        fileobj.write(chunk)
+                        size = fileobj.write(chunk)
+                        if bar is not None:
+                            bar.update(size)
         except (RetryError, HTTPError, ConnectTimeout,
                 ConnectionError, socket.error, ReadTimeout) as exc:
-            msg = ('error downloading file {0}, '
-                   'exception raised: {1}'.format(file_path, exc))
+            msg = f'error downloading file {file_path}, exception raised: {exc}'
             log.error(msg)
             if os.path.exists(file_path):
                 os.remove(file_path)
             if verbose:
-                print(' ' + msg)
-            elif silent is False:
-                print('e', end='')
-                sys.stdout.flush()
-            if ignore_errors is True:
+                print(f' {msg}', file=sys.stderr)
+            if ignore_errors:
                 return False
             else:
                 raise exc
@@ -305,15 +287,8 @@ class File(BaseFile):
                 # Probably file-like object, e.g. sys.stdout.
                 pass
 
-        msg = 'downloaded {0}/{1} to {2}'.format(self.identifier,
-                                                 self.name,
-                                                 file_path)
+        msg = f'downloaded {self.identifier}/{self.name} to {file_path}'
         log.info(msg)
-        if verbose:
-            print(' ' + msg)
-        elif silent is False:
-            print('d', end='')
-            sys.stdout.flush()
         return True
 
     def delete(self, cascade_delete=None, access_key=None, secret_key=None, verbose=None,
@@ -347,14 +322,12 @@ class File(BaseFile):
         debug = False if not debug else debug
         verbose = False if not verbose else verbose
         max_retries = 2 if retries is None else retries
-        headers = dict() if headers is None else headers
+        headers = {} if headers is None else headers
 
         if 'x-archive-cascade-delete' not in headers:
             headers['x-archive-cascade-delete'] = cascade_delete
 
-        url = '{0}//s3.us.archive.org/{1}/{2}'.format(self.item.session.protocol,
-                                                      self.identifier,
-                                                      urllib.parse.quote(self.name))
+        url = f'{self.item.session.protocol}//s3.us.archive.org/{self.identifier}/{quote(self.name)}'
         self.item.session.mount_http_adapter(max_retries=max_retries,
                                              status_forcelist=[503],
                                              host='s3.us.archive.org')
@@ -369,7 +342,7 @@ class File(BaseFile):
             return request
         else:
             if verbose:
-                msg = ' deleting: {0}'.format(self.name)
+                msg = f' deleting: {self.name}'
                 if cascade_delete:
                     msg += ' and all derivative files.'
                 print(msg, file=sys.stderr)
@@ -380,7 +353,7 @@ class File(BaseFile):
                 resp.raise_for_status()
             except (RetryError, HTTPError, ConnectTimeout,
                     ConnectionError, socket.error, ReadTimeout) as exc:
-                error_msg = 'Error deleting {0}, {1}'.format(url, exc)
+                error_msg = f'Error deleting {url}, {exc}'
                 log.error(error_msg)
                 raise
             else:
@@ -391,7 +364,7 @@ class File(BaseFile):
                 # mounted if and when the session object is used for an
                 # upload. This is important because we use custom retry
                 # handling for IA-S3 uploads.
-                url_prefix = '{0}//s3.us.archive.org'.format(self.item.session.protocol)
+                url_prefix = f'{self.item.session.protocol}//s3.us.archive.org'
                 del self.item.session.adapters[url_prefix]
 
 
@@ -405,4 +378,4 @@ class OnTheFlyFile(File):
         :param name: The filename of the file.
 
         """
-        super(OnTheFlyFile, self).__init__(item.item_metadata, name)
+        super().__init__(item.item_metadata, name)
