@@ -2,7 +2,7 @@
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
-# Copyright (C) 2012-2021 Internet Archive
+# Copyright (C) 2012-2022 Internet Archive
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -23,19 +23,25 @@ internetarchive.utils
 
 This module provides utility functions for the internetarchive library.
 
-:copyright: (C) 2012-2021 by Internet Archive.
+:copyright: (C) 2012-2022 by Internet Archive.
 :license: AGPL 3, see LICENSE for more details.
 """
 import hashlib
 import os
 import re
 import sys
-from itertools import starmap
 from xml.dom.minidom import parseString
+from collections.abc import Mapping
 
-import six
-from six.moves import zip_longest
-from six.moves.collections_abc import Mapping
+
+# Make preferred JSON package available via `from internetarchive.utils import json`
+try:
+    import ujson as json
+    # ujson lacks a JSONDecodeError: https://github.com/ultrajson/ultrajson/issues/497
+    JSONDecodeError = ValueError
+except ImportError:
+    import json
+    JSONDecodeError = json.JSONDecodeError
 
 
 def deep_update(d, u):
@@ -48,14 +54,6 @@ def deep_update(d, u):
     return d
 
 
-def map2x(func, *iterables):
-    """map() function for Python 2/3 compatibility"""
-    zipped = zip_longest(*iterables)
-    if func is None:
-        return zipped
-    return starmap(func, zipped)
-
-
 class InvalidIdentifierException(Exception):
     pass
 
@@ -91,9 +89,9 @@ def needs_quote(s):
 
 def norm_filepath(fp):
     fp = fp.replace(os.path.sep, '/')
-    if not fp[0] == '/':
-        fp = '/' + fp
-    if isinstance(fp, six.binary_type):
+    if not fp.startswith('/'):
+        fp = f'/{fp}'
+    if isinstance(fp, bytes):
         fp = fp.decode('utf-8')
     return fp
 
@@ -133,7 +131,7 @@ def suppress_keyboard_interrupt_message():
     sys.excepthook = new_hook
 
 
-class IterableToFileAdapter(object):
+class IterableToFileAdapter:
     def __init__(self, iterable, size):
         self.iterator = iter(iterable)
         self.length = size
@@ -145,7 +143,7 @@ class IterableToFileAdapter(object):
         return self.length
 
 
-class IdentifierListAsItems(object):
+class IdentifierListAsItems:
     """This class is a lazily-loaded list of Items, accessible by index or identifier.
     """
 
@@ -172,7 +170,7 @@ class IdentifierListAsItems(object):
             raise AttributeError
 
     def __repr__(self):
-        return '{0.__class__.__name__}({0.ids!r})'.format(self)
+        return f'{self.__class__.__name__}({self.ids!r})'
 
 
 def get_s3_xml_text(xml_str):
@@ -192,7 +190,7 @@ def get_s3_xml_text(xml_str):
         _resource = _get_tag_text('Resource', p)
         # Avoid weird Resource text that contains PUT method.
         if _resource and "'PUT" not in _resource:
-            return '{0} - {1}'.format(_msg, _resource.strip())
+            return f'{_msg} - {_resource.strip()}'
         else:
             return _msg
     except:
@@ -229,7 +227,7 @@ def recursive_file_count(files, item=None, checksum=False):
     if checksum is True:
         md5s = [f.get('md5') for f in item.files]
     else:
-        md5s = list()
+        md5s = []
     if isinstance(files, dict):
         # make sure to use local filenames.
         _files = files.values()
@@ -284,8 +282,8 @@ def reraise_modify(caught_exc, append_msg, prepend=False):
     Preserves exception class, and exception traceback.
 
     Note:
-        This function needs to be called inside an except because
-        `sys.exc_info()` requires the exception context.
+        This function needs to be called inside an except because an exception
+        must be active in the current scope.
 
     Args:
         caught_exc(Exception): The caught exception object
@@ -299,9 +297,6 @@ def reraise_modify(caught_exc, append_msg, prepend=False):
         Re-raises the exception with the preserved data / trace but
         modified message
     """
-    ExceptClass = type(caught_exc)
-    # Keep old traceback
-    traceback = sys.exc_info()[2]
     if not caught_exc.args:
         # If no args, create our own tuple
         arg_list = [append_msg]
@@ -321,9 +316,7 @@ def reraise_modify(caught_exc, append_msg, prepend=False):
         else:
             arg_list += [last_arg, append_msg]
     caught_exc.args = tuple(arg_list)
-    six.reraise(ExceptClass,
-                caught_exc,
-                traceback)
+    raise
 
 
 def remove_none(obj):
@@ -368,7 +361,7 @@ def is_valid_metadata_key(name):
     # are way more restrictive and only allow ".-A-Za-z_", possibly followed
     # by an index in square brackets e. g. [0].
     # On the other hand the Archive allows tags starting with the string "xml".
-    return bool(re.match(r'^[A-Za-z][.\-0-9A-Za-z_]+(?:\[[0-9]+\])?$', name))
+    return bool(re.fullmatch(r'[A-Za-z][.\-0-9A-Za-z_]+(?:\[[0-9]+\])?', name))
 
 
 def merge_dictionaries(dict0, dict1, keys_to_drop=None):
